% Scat 24-May-2020 

% 1. (If GrbSnd.mat file does not exist) Gather the sonde observations for 
%   which there are grab "matchups" i.e. those with times within 15 min of 
%   time of the grab, append them to the grabs table, and save to disk as
%   GrbSnd.mat.

% 2. Make scatterplots of sonde vs grabs data.

% basic initial setup
wipe;
modprelims;

% retrieve inputs
ingrps = { 'Config'; }; inputsdiary;

%% PART 1 (if needed)
if isfile('dat/GrbSnd.mat')
    load('dat/GrbSnd.mat');
else
    % get and group filenames
    dirdat = dir([in.snddir '*.mat']);
    for i = 1:length(stn)
        ctr = 0;
        for j = 1:length(dirdat)
            if isequal(dirdat(j).name(1:2),stn{i})
                ctr = ctr+1;
                allfil{i}{ctr} = dirdat(j).name;
            end
        end
    end

    % figure out max number of years
    nyr = 0; 
    for i = 1:length(stn)
        if length(allfil{i}) > nyr
            nyr = length(allfil{i});
        end
    end

    % load grabs data
    load(in.grabfil);
    GrbSnd = grabs;
    clear grabs;

    % add new empty columns to GrbSnd table for sonde (Snd) data
    GrbSnd.Snd15mnt = nan*ones(height(GrbSnd),1);
    GrbSnd.Snd1HrMin = nan*ones(height(GrbSnd),1);
    GrbSnd.Snd1HrAvg = nan*ones(height(GrbSnd),1);
    GrbSnd.Snd1HrMax = nan*ones(height(GrbSnd),1);
    GrbSnd.Snd3HrMin = nan*ones(height(GrbSnd),1);
    GrbSnd.Snd3HrAvg = nan*ones(height(GrbSnd),1);
    GrbSnd.Snd3HrMax = nan*ones(height(GrbSnd),1);
    GrbSnd.Snd8HrMin = nan*ones(height(GrbSnd),1);
    GrbSnd.Snd8HrAvg = nan*ones(height(GrbSnd),1);
    GrbSnd.Snd8HrMax = nan*ones(height(GrbSnd),1);
    % fill sonde portions of GrbSnd
    for i = 1:length(stn)
        fprintf('   working on stn %d of %d\n',i,length(stn));
        iyrsgrb = unique(year(GrbSnd.Date(ismember(GrbSnd.Station,stn(i)))))-2000;
        for j = 1:length(allfil{i}) % one year at a time
            iyr = str2num(allfil{i}{j}(5:6));
            if ~isempty(find(ismember(iyrsgrb,iyr)))
                fprintf('      year %d\n',iyr+2000);
                snd = load([in.snddir allfil{i}{j}]);
                dnests = GrbSnd.dnest( year(GrbSnd.Date)-2000==iyr & ...
                                     ismember(GrbSnd.Station,stn(i)) );
                for idnest = 1:length(dnests)
                    ind = find(abs(snd.qh.dnest-dnests(idnest))<0.125/24);
                    if ~isempty(ind)
                        GrbSnd.Snd15mnt(GrbSnd.dnest==dnests(idnest) & ...
                            ismember(GrbSnd.Station,stn(i)) ) = ...
                             max([0.1 snd.qh.sh.chl(ind)],[],'includenan');
                    end
                    ind = find(abs(snd.qh.dnest-dnests(idnest))<0.5/24);
                    if ~isempty(ind)
                        GrbSnd.Snd1HrMin(GrbSnd.dnest==dnests(idnest) & ...
                            ismember(GrbSnd.Station,stn(i)) ) = ...
                    max([0.1 nanmin(snd.qh.sh.chl(ind))],[],'includenan');
                        GrbSnd.Snd1HrAvg(GrbSnd.dnest==dnests(idnest) & ...
                            ismember(GrbSnd.Station,stn(i)) ) = ...
                    max([0.1 nanmean(snd.qh.sh.chl(ind))],[],'includenan');
                        GrbSnd.Snd1HrMax(GrbSnd.dnest==dnests(idnest) & ...
                            ismember(GrbSnd.Station,stn(i)) ) = ...
                    max([0.1 nanmax(snd.qh.sh.chl(ind))],[],'includenan');
                    end
                    ind = find(abs(snd.qh.dnest-dnests(idnest))<1.5/24);
                    if ~isempty(ind)
                        GrbSnd.Snd3HrMin(GrbSnd.dnest==dnests(idnest) & ...
                            ismember(GrbSnd.Station,stn(i)) ) = ...
                    max([0.1 nanmin(snd.qh.sh.chl(ind))],[],'includenan');
                        GrbSnd.Snd3HrAvg(GrbSnd.dnest==dnests(idnest) & ...
                            ismember(GrbSnd.Station,stn(i)) ) = ...
                    max([0.1 nanmean(snd.qh.sh.chl(ind))],[],'includenan');
                        GrbSnd.Snd3HrMax(GrbSnd.dnest==dnests(idnest) & ...
                            ismember(GrbSnd.Station,stn(i)) ) = ...
                    max([0.1 nanmax(snd.qh.sh.chl(ind))],[],'includenan');
                    end
                    ind = find(abs(snd.qh.dnest-dnests(idnest))<4/24);
                    if ~isempty(ind)
                        GrbSnd.Snd8HrMin(GrbSnd.dnest==dnests(idnest) & ...
                            ismember(GrbSnd.Station,stn(i)) ) = ...
                    max([0.1 nanmin(snd.qh.sh.chl(ind))],[],'includenan');
                        GrbSnd.Snd8HrAvg(GrbSnd.dnest==dnests(idnest) & ...
                            ismember(GrbSnd.Station,stn(i)) ) = ...
                    max([0.1 nanmean(snd.qh.sh.chl(ind))],[],'includenan');
                        GrbSnd.Snd8HrMax(GrbSnd.dnest==dnests(idnest) & ...
                            ismember(GrbSnd.Station,stn(i)) ) = ...
                    max([0.1 nanmax(snd.qh.sh.chl(ind))],[],'includenan');
                    end
                    clear ind;
                end
                clear sdn dnests idnest;
            end
            clear iyr;
        end
        clear j iyrsgrb;
    end
    save dat/GrbSnd GrbSnd;
end

% PART 2 - scatterplots
for istn = 1:length(stn)
    dat = GrbSnd(ismember(GrbSnd.Station,stn(istn)),:); 
    figport('on');

    mn = 0;
    mx = 1.02*nanmax(nanmax([dat.val1; dat.val2; dat.val3;]),...
                     nanmax([dat.Snd1HrMax; dat.Snd3HrMax; dat.Snd8HrMax;]));
    subplot(4,2,1);
    hold;
    for i = 1:length(dat.val1)
        x = [dat.val1(i) dat.val2(i) dat.val3(i)];
        x = x(~isnan(x));
        y = dat.Snd15mnt(i)*ones(size(x));
        plot(x,y,'k.');
        plot(x,y,'k-');
        clear x y;
    end
    clear i;
    ylabel('sonde: 15min ug/L');
    title(stn{istn}); 
    xlim([mn mx]);
    ylim([mn mx]);
    plot([mn mx],[mn mx],'k-'); 

    subplot(4,2,2);
    hold;
    for i = 1:length(dat.val1)
        x = [dat.val1(i) dat.val2(i) dat.val3(i)];
        x = x(~isnan(x));
        y = dat.Snd15mnt(i)*ones(size(x));
        plot(x,y,'k.');
        plot(x,y,'k-');
        clear x y;
    end
    clear i;
    title(stn{istn});
    set(gca, 'YScale', 'log');
    set(gca, 'XScale', 'log');
    xlim([0.1 logscmax]);
    ylim([0.1 logscmax]);
    plot([0.1 logscmax],[0.1 logscmax],'k-'); 

    subplot(4,2,3);
    hold;
    for i = 1:length(dat.val1)
        x = [dat.val1(i) dat.val2(i) dat.val3(i)];
        x = x(~isnan(x));
        y = dat.Snd1HrAvg(i)*ones(size(x));
        plot(x,y,'k.');
        plot(x,y,'k-');
        clear x y;
        y = [dat.Snd1HrMin(i) dat.Snd1HrAvg(i) dat.Snd1HrMax(i)];
        y = y(~isnan(y));
        x = dat.mean(i)*ones(size(y));
        plot(x,y,'k.');
        plot(x,y,'k-');
        clear x y;        
    end
    clear i;
    ylabel('sonde: 1hr min-avg-max ug/L');
    xlim([mn mx]);
    ylim([mn mx]);
    plot([mn mx],[mn mx],'k-'); 
    
    subplot(4,2,4);
    hold;
    for i = 1:length(dat.val1)
        x = [dat.val1(i) dat.val2(i) dat.val3(i)];
        x = x(~isnan(x));
        y = dat.Snd1HrAvg(i)*ones(size(x));
        plot(x,y,'k.');
        plot(x,y,'k-');
        clear x y;
        y = [dat.Snd1HrMin(i) dat.Snd1HrAvg(i) dat.Snd1HrMax(i)];
        y = y(~isnan(y));
        x = dat.mean(i)*ones(size(y));
        plot(x,y,'k.');
        plot(x,y,'k-');
        clear x y;        
    end
    clear i;
    set(gca, 'YScale', 'log');
    set(gca, 'XScale', 'log');
    xlim([0.1 logscmax]);
    ylim([0.1 logscmax]);
    plot([0.1 logscmax],[0.1 logscmax],'k-'); 

    subplot(4,2,5);
    hold;
    for i = 1:length(dat.val1)
        x = [dat.val1(i) dat.val2(i) dat.val3(i)];
        x = x(~isnan(x));
        y = dat.Snd3HrAvg(i)*ones(size(x));
        plot(x,y,'k.');
        plot(x,y,'k-');
        clear x y;
        y = [dat.Snd3HrMin(i) dat.Snd3HrAvg(i) dat.Snd3HrMax(i)];
        y = y(~isnan(y));
        x = dat.mean(i)*ones(size(y));
        plot(x,y,'k.');
        plot(x,y,'k-');
        clear x y;        
    end
    clear i;
    ylabel('sonde: 3hr min-avg-max ug/L');
    xlim([mn mx]);
    ylim([mn mx]);
    plot([mn mx],[mn mx],'k-'); 
    
    subplot(4,2,6);
    hold;
    for i = 1:length(dat.val1)
        x = [dat.val1(i) dat.val2(i) dat.val3(i)];
        x = x(~isnan(x));
        y = dat.Snd3HrAvg(i)*ones(size(x));
        plot(x,y,'k.');
        plot(x,y,'k-');
        clear x y;
        y = [dat.Snd3HrMin(i) dat.Snd3HrAvg(i) dat.Snd3HrMax(i)];
        y = y(~isnan(y));
        x = dat.mean(i)*ones(size(y));
        plot(x,y,'k.');
        plot(x,y,'k-');
        clear x y;        
    end
    clear i;
    set(gca, 'YScale', 'log');
    set(gca, 'XScale', 'log');
    xlim([0.1 logscmax]);
    ylim([0.1 logscmax]);
    plot([0.1 logscmax],[0.1 logscmax],'k-'); 

    subplot(4,2,7);
    hold;
    for i = 1:length(dat.val1)
        x = [dat.val1(i) dat.val2(i) dat.val3(i)];
        x = x(~isnan(x));
        y = dat.Snd8HrAvg(i)*ones(size(x));
        plot(x,y,'k.');
        plot(x,y,'k-');
        clear x y;
        y = [dat.Snd8HrMin(i) dat.Snd8HrAvg(i) dat.Snd8HrMax(i)];
        y = y(~isnan(y));
        x = dat.mean(i)*ones(size(y));
        plot(x,y,'k.');
        plot(x,y,'k-');
        clear x y;        
    end
    clear i;
    xlabel('grab: indiv values ug/L');
    ylabel('sonde: 8hr min-avg-max ug/L');
    xlim([mn mx]);
    ylim([mn mx]);
    plot([mn mx],[mn mx],'k-'); 
    
    subplot(4,2,8);
    hold;
    for i = 1:length(dat.val1)
        x = [dat.val1(i) dat.val2(i) dat.val3(i)];
        x = x(~isnan(x));
        y = dat.Snd8HrAvg(i)*ones(size(x));
        plot(x,y,'k.');
        plot(x,y,'k-');
        clear x y;
        y = [dat.Snd8HrMin(i) dat.Snd8HrAvg(i) dat.Snd8HrMax(i)];
        y = y(~isnan(y));
        x = dat.mean(i)*ones(size(y));
        plot(x,y,'k.');
        plot(x,y,'k-');
        clear x y;        
    end
    clear i;
    xlabel('grab: indiv values ug/L');
    set(gca, 'YScale', 'log');
    set(gca, 'XScale', 'log');
    xlim([0.1 logscmax]);
    ylim([0.1 logscmax]);
    plot([0.1 logscmax],[0.1 logscmax],'k-'); 

    eval(sprintf('print -dpng plt/Scat%d%s;',istn,stn{istn}));
    delete(gcf);
    clear mn mx;
end
clear istn;

% end of module
diary off;